@@ -1,5 +1,5 @@
-/* -*- mode: c; c-basic-offset: 4; tab-width: 4; indent-tabs-mode: t -*-
- * vim: ts=4 sw=4 noet ai cindent syntax=c
+/* -*- mode: c++; c-basic-offset: 4; tab-width: 4; indent-tabs-mode: t -*-
+ * vim: ts=4 sw=4 noet ai cindent syntax=cpp
  *
  * Conky, a system monitor, based on torsmo
  *
@@ -10,7 +10,7 @@
  * Please see COPYING for details
  *
  * Copyright (c) 2004, Hannu Saransaari and Lauri Hakkarainen
- * Copyright (c) 2005-2010 Brenden Matthews, Philip Kovacs, et. al.
+ * Copyright (c) 2005-2012 Brenden Matthews, Philip Kovacs, et. al.
  *	(see AUTHORS)
  * All rights reserved.
  *
@@ -31,10 +31,14 @@
 #ifndef _conky_h_
 #define _conky_h_
 
-#include "config.h"	/* defines */
+#define __STDC_FORMAT_MACROS
+
+#include <config.h>	/* defines */
 #include "common.h"	/* at least for struct dns_data */
 #include <sys/utsname.h> /* struct uname_s */
 #include <arpa/inet.h>
+#include <memory>
+#include "luamm.hh"
 
 #if defined(HAS_MCHECK_H)
 #include <mcheck.h>
@@ -66,71 +70,54 @@ char *strndup(const char *s, size_t n);
 /* forward define to make gcc happy */
 struct text_object;
 
-#ifdef AUDACIOUS
-#include "audacious.h"
-#endif
-
-#ifdef BMPX
+#ifdef BUILD_BMPX
 #include "bmpx.h"
-#endif
+#endif /* BUILD_BMPX */
 
-#ifdef EVE
+#ifdef BUILD_EVE
 #include "eve.h"
-#endif
+#endif /* BUILD_EVE */
 
-#ifdef HDDTEMP
+#ifdef BUILD_HDDTEMP
 #include "hddtemp.h"
-#endif /* HDDTEMP */
+#endif /* BUILD_HDDTEMP */
 
-#ifdef MOC
+#ifdef BUILD_MOC
 #include "moc.h"
-#endif
+#endif /* BUILD_MOC */
 
-#ifdef MPD
+#ifdef BUILD_MPD
 #include "mpd.h"
-#endif
+#endif /* BUILD_MPD */
 
-#ifdef HAVE_CURL
-#include "ccurl_thread.h"
-#endif /* HAVE_CURL */
+#ifdef BUILD_MYSQL
+#include "mysql.h"
+#endif /* BUILD_MYSQL */
 
-#ifdef RSS
-#include "rss.h"
-#endif /* RSS */
+#ifdef BUILD_WEATHER_XOAP
+#ifndef BUILD_WEATHER_METAR
+#error "BUILD_WEATHER_METAR needs to be defined if XOAP is defined"
+#endif /* BUILD_WEATHER_METAR */
+#endif /* BUILD_WEATHER_XOAP */
 
-#ifdef XOAP
-#ifndef WEATHER
-#error "WEATHER needs to be defined if XOAP is defined"
-#endif /* WEATHER */
-#endif /* XOAP */
-
-#ifdef WEATHER
-#include "weather.h"
-#endif /* WEATHER */
-
-#ifdef TCP_PORT_MONITOR
+#ifdef BUILD_PORT_MONITORS
 #include "tcp-portmon.h"
 #endif
 
-#ifdef XMMS2
+#ifdef BUILD_XMMS2
 #include "xmms2.h"
-#endif
+#endif /* BUILD_XMMS2 */
 
-#ifdef IBM
-#include "ibm.h"
-#include "smapi.h"
-#endif
-
-#ifdef APCUPSD
+#ifdef BUILD_APCUPSD
 #include "apcupsd.h"
-#endif
+#endif /* BUILD_APCUPSD */
 
 /* sony support */
 #include "sony.h"
 
 /* A size for temporary, static buffers to use when
  * one doesn't know what to choose. Defaults to 256.  */
-extern unsigned int text_buffer_size;
+extern conky::range_config_setting<unsigned int> text_buffer_size;
 
 struct usr_info {
 	char *names;
@@ -140,7 +127,7 @@ struct usr_info {
 	int number;
 };
 
-#ifdef X11
+#ifdef BUILD_X11
 struct monitor_info {
 	int number;
 	int current;
@@ -149,9 +136,8 @@ struct monitor_info {
 struct desktop_info {
         int current;
         int number;
-        unsigned int nitems;
-        char *all_names;
-        char *name;
+		std::string all_names;
+		std::string name;
 };
 
 struct x11_info {
@@ -159,22 +145,7 @@ struct x11_info {
 	struct desktop_info desktop;
 };
 
-int get_stippled_borders(void);
-
-#endif /* X11 */
-
-/* defined in conky.c */
-extern long default_fg_color, default_bg_color, default_out_color;
-extern long color0, color1, color2, color3, color4, color5, color6, color7,
-	   color8, color9;
-void set_current_text_color(long colour);
-long get_current_text_color(void);
-
-void set_updatereset(int);
-int get_updatereset(void);
-
-int percent_print(char *, int, unsigned);
-void human_readable(long long, char *, int);
+#endif /* BUILD_X11 */
 
 struct conftree {
 	char* string;
@@ -183,53 +154,36 @@ struct conftree {
 	struct conftree* back;
 };
 
-char load_config_file(const char *);
+void load_config_file();
 
 char *get_global_text(void);
 extern long global_text_lines;
 
-//adds newstring to to the tree unless you can already see it when travelling back.
-//if it's possible to attach it then it returns a pointer to the leaf, else it returns NULL
-struct conftree* conftree_add(struct conftree* previous, const char* newstring);
-
-extern struct conftree *currentconffile;
-
 #define MAX_TEMPLATES 10
 char **get_templates(void);
 
-/* get_xxxxx_stuff() item selector
+/* get_battery_stuff() item selector
  * needed by conky.c, linux.c and freebsd.c */
 enum {
 	BATTERY_STATUS,
-	BATTERY_TIME,
-	BATTERY_VOLTS,
-	BATTERY_TEMP,
-	DBUS_CELL_DBM,
-	DBUS_CELL_PERCENT,
-	DBUS_HAL_BATTERY_CHRG_STATUS,
-	DBUS_HAL_BATTERY_PERCENT,
-	DBUS_HAL_BATTERY_VOLTS_CURRENT
+	BATTERY_TIME
 };
 
-/* if_up strictness selector
- * needed by conky.c and linux.c (and potentially others) */
-enum {
-	IFUP_UP,
-	IFUP_LINK,
-	IFUP_ADDR
-} ifup_strictness;
-
 struct information {
 	unsigned int mask;
 
 	struct utsname uname_s;
+#if defined(__DragonFly__)
+    char uname_v[256]; /* with git version */
+#endif
 
 	char freq[10];
 
 	double uptime;
 
 	/* memory information in kilobytes */
-	unsigned long long mem, memeasyfree, memfree, memmax, swap, swapfree, swapmax;
+	unsigned long long mem, memwithbuffers, memeasyfree, memfree, memmax, memdirty;
+    unsigned long long swap, swapfree, swapmax;
 	unsigned long long bufmem, buffers, cached;
 
 	unsigned short procs;
@@ -240,48 +194,48 @@ struct information {
 	float *cpu_usage;
 	/* struct cpu_stat cpu_summed; what the hell is this? */
 	int cpu_count;
-	int cpu_avg_samples;
-
-	int net_avg_samples;
-
-	int diskio_avg_samples;
 
 	float loadavg[3];
 
-#ifdef XMMS2
+#ifdef BUILD_XMMS2
 	struct xmms2_s xmms2;
-#endif
-#ifdef AUDACIOUS
-	AUDACIOUS_S audacious;
-#endif
-#ifdef BMPX
+#endif /* BUILD_XMMS2 */
+#ifdef BUILD_BMPX
 	struct bmpx_s bmpx;
-#endif
+#endif /* BUILD_BMPX */
 	struct usr_info users;
 	struct process *cpu[10];
 	struct process *memu[10];
 	struct process *time[10];
-#ifdef IOSTATS
+#ifdef BUILD_IOSTATS
 	struct process *io[10];
-#endif
+#endif /* BUILD_IOSTATS */
 	struct process *first_process;
 	unsigned long looped;
-	double music_player_interval;
 
-#ifdef X11
+#ifdef BUILD_X11
 	struct x11_info x11;
-#endif
-
-#ifdef APCUPSD
-	APCUPSD_S apcupsd;
-#endif
+#endif /* BUILD_X11 */
 
 	short kflags;	/* kernel settings, see enum KFLAG */
 };
 
-#ifdef HAVE_LUA
-#include "llua.h"
-#endif /* HAVE_LUA */
+class music_player_interval_setting: public conky::simple_config_setting<double> {
+	typedef conky::simple_config_setting<double> Base;
+
+protected:
+	virtual void lua_setter(lua::state &l, bool init);
+
+public:
+	music_player_interval_setting()
+		: Base("music_player_interval", 0, true)
+	{}
+};
+extern music_player_interval_setting music_player_interval;
+
+extern conky::range_config_setting<int> cpu_avg_samples;
+extern conky::range_config_setting<int> net_avg_samples;
+extern conky::range_config_setting<int> diskio_avg_samples;
 
 /* needed by linux.c and top.c -> outsource somewhere */
 enum {
@@ -300,24 +254,30 @@ enum {
 
 /* defined in conky.c, needed by top.c */
 extern int top_cpu, top_mem, top_time;
-#ifdef IOSTATS
+#ifdef BUILD_IOSTATS
 extern int top_io;
-#endif
+#endif /* BUILD_IOSTATS */
 extern int top_running;
 
-/* defined in conky.c, needed by top.c */
-extern int cpu_separate;
-
 /* struct that has all info to be shared between
  * instances of the same text object */
 extern struct information info;
 
-/* defined in users.c */
-int update_users(void);
-void update_user_time(char *tty);
-
 /* defined in conky.c */
-extern double current_update_time, last_update_time, update_interval;
+extern double current_update_time, last_update_time;
+
+extern conky::range_config_setting<double> update_interval;
+extern conky::range_config_setting<double> update_interval_on_battery;
+double active_update_interval();
+
+extern conky::range_config_setting<char>  stippled_borders;
+
+void set_current_text_color(long colour);
+long get_current_text_color(void);
+
+void set_updatereset(int);
+int get_updatereset(void);
+int get_total_updates(void);
 
 /* defined in conky.c */
 int spaced_print(char *, int, const char *, int, ...)
@@ -329,31 +289,20 @@ extern int inotify_fd;
  */
 void evaluate(const char *text, char *p, int p_max_size);
 
+void parse_conky_vars(struct text_object *, const char *, char *, int);
+
+void extract_object_args_to_sub(struct text_object *, const char *);
+
+void generate_text_internal(char *, int, struct text_object);
+
+int percent_print(char *, int, unsigned);
+void human_readable(long long, char *, int);
+
 /* maximum size of config TEXT buffer, i.e. below TEXT line. */
-extern unsigned int max_user_text;
+extern conky::range_config_setting<unsigned int> max_user_text;
 
 /* path to config file */
-extern char *current_config;
-
-#ifdef X11
-#define TO_X 1
-#endif /* X11 */
-#define TO_STDOUT 2
-#define TO_STDERR 4
-#define OVERWRITE_FILE 8
-#define APPEND_FILE 16
-#ifdef NCURSES
-#define TO_NCURSES 32
-#endif /* NCURSES */
-enum x_initialiser_state {
-	NO = 0,
-	YES = 1,
-	NEVER = 2
-};
-extern int output_methods;
-extern enum x_initialiser_state x_initialised;
-
-void set_update_interval(double interval);
+extern std::string current_config;
 
 #define DEFAULT_TEXT_BUFFER_SIZE_S "##DEFAULT_TEXT_BUFFER_SIZE"
 
@@ -363,9 +312,17 @@ void set_update_interval(double interval);
 #define UNUSED(a)  (void)a
 #define UNUSED_ATTR __attribute__ ((unused))
 
-void parse_conky_vars(struct text_object *, const char *,
-			char *, int, struct information *);
+template <class T>
+void free_and_zero(T *&ptr) {
+	if(ptr) {
+		free(ptr);
+		ptr = NULL;
+	}
+}
+
+extern std::unique_ptr<lua::state> state;
+
+extern int argc_copy;
+extern char** argv_copy;
 
-void generate_text_internal(char *, int, struct text_object,
-                                   struct information *);
 #endif /* _conky_h_ */
