@@ -1,3 +1,5 @@
+/* -*- mode: c; c-basic-offset: 4; tab-width: 4; indent-tabs-mode: t -*- */
+
 #ifndef FREEBSD_H_
 #define FREEBSD_H_
 
@@ -11,6 +13,7 @@
 #include <machine/apm_bios.h>
 #endif /* i386 || __i386__ */
 
-kvm_t *kd;
+int get_entropy_avail(unsigned int *);
+int get_entropy_poolsize(unsigned int *);
 
 #endif /*FREEBSD_H_*/
